/**************************************************************************************************************
 *
 * PIC18F6620-Modul
 *
 * "Hello World" zur Inbetriebnahme
 *
 * Datei : Hello.c
 *
 * Autor : Finger
 *
 * Controller : Microchip 18F6620, 40 Mhz
 * Einstellungen:  OSC=HS, WDT=OFF, PWT=ON, CP=OFF, BOD=ON, LVP=OFF
 *
 * TAB-Space : 2
 * Editor : MI-Edit
 * Entwicklungsumgebung : Hi-Tech PIC-C 18 (www.htsoft.com)
 *
 *************************************************************************************************************/

#include	<pic18.h>
#include	<stdlib.h>
#include	<stdio.h>
#include  <string.h>
#include  "defines.h"
#include  "serial.h"

//----------------------------------------------------------
// Rckgabepuffer fr INT -> ASCII-Wandlung und Textausgabe
//----------------------------------------------------------
char outpbuf [Buflen];

//---------------------------------
// Konfiguration des Controllers
// Fr Kartendatei auskommentieren
//---------------------------------
__CONFIG(1, OSCSEN & HSPLL);       // Quarz 10 Mhz mit PLL = 40 Mhz
__CONFIG(2, BORDIS & WDTDIS);      // Kein Watchdog, kein BrownOut
__CONFIG(4, LVPDIS & STVREN);      // Kein LowVoltageProgramm, Reset bei StackOverflow

/***************
 *
 * Zentrale ISR
 *
 ***************/
interrupt void INT_(void)
 {

   //------------------
   // USART-Behandlung
   //------------------
   isr_usart ();

   //--------------------
   // Timer 1 berlauf ?
   //--------------------
   if (TMR1IF)
   	{

      //-------------------
      // Ablauf alle 5 ms
      //-------------------
      TMR1IF=0;                                         // Clear Interrupt-Flag
      TMR1H=0xE7;                                       // n = 2^16 - t [s] * 625000
      TMR1L=0x96;                                       // Timer 1 neu vorladen (0xE796 = 5 ms)

   	} // From Timer 1 berlauf

   return;									                     // Zurck zum Hauptprogramm
 }

/***************************
 *
 * Initialisierungsroutinen
 *
 ***************************/
void sysinit (void)
 {

  //--------------------
  // IO-Ports klarmachen
  //--------------------

  // Alle Ports initialisieren bzw. auf Null setzen
  PORTA = 0;
  PORTB = 0;
  PORTC = 0;
  PORTD = 0;
  PORTE = 0;
  PORTF = 0;

  //-------------------------
  // Comperatoren abschalten
  //-------------------------
  CMCON = 0x07;

  // Ein- Ausgangsdefinitionen, 0 = Output / 1 Input, siehe Schaltplan
  TRISA = 0b11000111;  //
  TRISB = 0b11100001;  //
  TRISC = 0b10100010;  //
  TRISD = 0b00000000;  //
  TRISE = 0b00000000;  //
  TRISF = 0b11111111;  //
  TRISG = 0b11100100;  //

  //-----------------
  // UARTS klarmachen
  //-----------------
  UART_Init ();

  //-------------------------------------
  // Timer 1 als Systemticker einrichten
  //-------------------------------------
  /*
  TMR1IE=1;									                        // enable Interrupt of TMR1
  T1CON=49;									                        // Prescaler=1:8 + Timer on (49)

  //--------------------
  // Alle Interrupts an
  //--------------------
  PEIE=1;          							                    // Peripherie Int=on
  GIE=1;										                        // Define Interupts
    */
 }

/*************
 *
 * Main
 *
 *************/
void main (void)
{

  //----------------------
  // System initialisieren
  //----------------------
  sysinit ();

  //---------------
  // Hauptschleife
  //---------------
  while (1)
   {
    put_string_usart (UART1, "PIC18F6620-Modul Hello World\n\r");
    put_string_usart (UART2, "(C) 2005 www.Fingers-welt.de\n\r");
   } // Von while (1)

}

// Thats all folks !


